===============================
spanky
===============================

.. image:: https://badge.fury.io/py/spanky.png
    :target: http://badge.fury.io/py/spanky

.. image:: https://travis-ci.org/ionrock/spanky.png?branch=master
        :target: https://travis-ci.org/ionrock/spanky

.. image:: https://pypip.in/d/spanky/badge.png
        :target: https://pypi.python.org/pypi/spanky


Idempotent devops.

A collection of cli tools and nice DSL for doing devops.

::
   $ cat tests/etc/spanky/users.yml
   ---
   - username: mimi
   $ sp -c tests/etc/spanky/ users

User mimi has been created!!!!!

* Free software: BSD license
* Documentation: https://spanky.readthedocs.org.

Features
--------

* TODO
